@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -125,6 +125,16 @@ sub validateRow()
     my $action = shift;
 }
 
+
+sub validateTypedRow
+{
+    my ($self, $action, $newValues) = @_;
+    if ($action eq 'add') {
+        $self->_checkName($newValues->{name}->value())
+    }
+}
+
+
 # Method: addObject
 #
 #   Add object to the objects table. Note this method must exist
@@ -163,6 +173,8 @@ sub addObject
         throw EBox::Exceptions::MissingArgument('name');
     }
 
+    $self->_checkName($name);
+
    my $id = $self->addRow('name' => $name, 'id' => $params{'id'});
    unless (defined($id)) {
        throw EBox::Exceptions::Internal("Couldn't add object's name: $name");
@@ -187,5 +199,29 @@ sub _objectHelp
               'is automatically synched in all the modules using it');
 }
 
+
+sub _checkName
+{
+    my ($self, $name) = @_;
+    if (uc $name eq 'ANY') {
+        throw EBox::Exceptions::External(
+__(q{'Any' is a reserved word that could not be used as object name to avoid confusions})
+                                        );
+    }
+
+    if ($name =~ m/^\d+\.\d+\.\d+\.\d+$/) {
+        throw EBox::Exceptions::External(
+         'A object could not be named like a IP address'
+                                        );
+    }
+
+    if ($name =~ m{^\d+\.\d+\.\d+\.\d+/\d+$}) {
+        throw EBox::Exceptions::External(
+         'A object could not be named like a IP address with netmask'
+                                        );
+    }
+}
+
+
 1;
 
